@@ -44,8 +44,11 @@ def _warn_about_pytz_usage() -> None:
 
 def get_timezones() -> set[str]:
     """Determine the timezone provider and return available timezones."""
-    if _is_available('zoneinfo') and _is_available('tzdata'):  # pragma: no cover
-        return _tz_provider_from_zone_info()
+    if _is_available('zoneinfo'):  # pragma: no cover
+        timezones = _tz_provider_from_zone_info()
+        if len(timezones) == 0:  # pragma: no cover
+            raise ImportError('No timezone provider found. Please install tzdata with "pip install tzdata"')
+        return timezones
     elif _is_available('pytz'):  # pragma: no cover
         return _tz_provider_from_pytz()
     else:  # pragma: no cover
@@ -57,7 +60,7 @@ def get_timezones() -> set[str]:
 class TimeZoneNameSettings(type):
     def __new__(cls, name: str, bases: tuple[type, ...], dct: dict[str, Any], **kwargs: Any) -> type[TimeZoneName]:
         dct['strict'] = kwargs.pop('strict', True)
-        return cast(type[TimeZoneName], super().__new__(cls, name, bases, dct))
+        return cast('type[TimeZoneName]', super().__new__(cls, name, bases, dct))
 
     def __init__(cls, name: str, bases: tuple[type, ...], dct: dict[str, Any], **kwargs: Any) -> None:
         super().__init__(name, bases, dct)
